
import pytest

from pathlib import Path

from pyat.ingestion.IngestionManifest import IngestionManifest
from pyat.ingestion.IngestionManifest import INGESTION_MANIFEST_FILE
import pyat.ingestion.manifestpersist as mp
from pyat.ingestion.JSONMetadataUtil import JSONMetadata
from pyat.ingestion.RealFastMetadata import RealFastMetadata
from pyat.schema import RealfastExecutionBlock


@pytest.fixture
def ingestion_manifest():
    ingestion_manifest = IngestionManifest(INGESTION_MANIFEST_FILE)
    return ingestion_manifest

@pytest.fixture
def realfast_metadata():
    manifest = IngestionManifest(INGESTION_MANIFEST_FILE)
    if manifest.has_collection():
        collection_metadata_file = Path(".") / manifest.get_additional_metadata_file()
        json_metadata = JSONMetadata(collection_metadata_file)
        if json_metadata.isRealFast():
            realfast_metadata = RealFastMetadata(json_metadata)
            return realfast_metadata
        else:
            return None
    else:
        return None


@pytest.mark.skip(reason='Ignoring for now')
def test_associate_group(ingestion_manifest):
    assert ingestion_manifest.get_associate_group_locator() == "uid://evla/execblock/abcd-efgh-ijkl-mnop"


@pytest.mark.skip(reason='Ignoring for now')
def test_type(realfast_metadata):
    assert type(realfast_metadata) == RealFastMetadata


#TODO
# NGAS files
@pytest.mark.skip(reason='Ignoring for now')
def test_realfast_attributes(realfast_metadata):
    assert realfast_metadata.get_transient_dm() == 576.9
    assert realfast_metadata.get_transient_ra() == "01:55:50.2715"
    assert realfast_metadata.get_transient_ra_error() == 0.05664506927973141
    assert realfast_metadata.get_transient_dec() == "+31:27:54.8557"
    assert realfast_metadata.get_transient_dec_error() == 0.8496760391959711
    assert realfast_metadata.get_transient_snr() == 7.483555793762207
    assert realfast_metadata.get_transient_dm() == 576.9
    assert realfast_metadata.get_transient_dm_error() == 576.9
    assert realfast_metadata.get_preaverage_time() == 0.019999999999999997
    assert realfast_metadata.get_rfpipe_version() == "1.5.7"
    assert realfast_metadata.get_prefs_id() == "f245c8a5fad6005dbe85fbee85428b4d"
    assert realfast_metadata.get_rf_qa_label() == "Questionable"
    assert realfast_metadata.get_rf_qa_zero_fraction() == 0.2119006529116276
    assert realfast_metadata.get_rf_qa_visibility_noise() == 0.017208602279424667
    assert realfast_metadata.get_rf_qa_image_noise() == 847.9179077148438


@pytest.mark.skip(reason='Ignoring for now')
def test_realfast_execution_block(realfast_metadata):
    execution_block = RealfastExecutionBlock()
    assert type(execution_block) == RealfastExecutionBlock
    execution_block.transient_ra = realfast_metadata.get_transient_ra()
    assert execution_block.transient_ra == realfast_metadata.get_transient_ra()


def test_manifest():
    path = Path("./tests")
    manifest = IngestionManifest(path / INGESTION_MANIFEST_FILE)
    assert manifest.has_collection_metadata_file()

